@@ -5,15 +5,15 @@ import (
 	"os"
 	stdruntime "runtime"
 	"slices"
-	"strings"
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
+	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
+	"github.com/jandedobbeleer/oh-my-posh/src/text"
 	"github.com/spf13/cobra"
 )
 
@@ -21,7 +21,7 @@ var (
 	force bool
 )
 
-// noticeCmd represents the get command
+// upgradeCmd represents the upgrade command
 var upgradeCmd = &cobra.Command{
 	Use:   "upgrade",
 	Short: "Upgrade when a new version is available.",
@@ -32,8 +32,7 @@ var upgradeCmd = &cobra.Command{
 
 		if debug {
 			startTime = time.Now()
-			log.Enable()
-			log.Debug("debug mode enabled")
+			log.Enable(plain)
 		}
 
 		supportedPlatforms := []string{
@@ -58,9 +57,7 @@ var upgradeCmd = &cobra.Command{
 		terminal.Init(sh)
 		fmt.Print(terminal.StartProgress())
 
-		configFile := config.Path(configFlag)
-		cfg, _ := config.Load(configFile, sh, false)
-		cfg.Upgrade.Cache = env.Cache()
+		cfg, _ := config.Load(configFlag, sh, false)
 
 		defer func() {
 			fmt.Print(terminal.StopProgress())
@@ -74,14 +71,14 @@ var upgradeCmd = &cobra.Command{
 				return
 			}
 
-			var builder strings.Builder
+			sb := text.NewBuilder()
 
-			builder.WriteString(fmt.Sprintf("%s %s\n", log.Text("Upgrade duration:").Green().Bold().Plain(), time.Since(startTime)))
+			sb.WriteString(fmt.Sprintf("%s %s\n", log.Text("Upgrade duration:").Green().Bold().Plain(), time.Since(startTime)))
 
-			builder.WriteString(log.Text("\nLogs:\n\n").Green().Bold().Plain().String())
-			builder.WriteString(env.Logs())
+			sb.WriteString(log.Text("\nLogs:\n\n").Green().Bold().Plain().String())
+			sb.WriteString(env.Logs())
 
-			fmt.Println(builder.String())
+			fmt.Println(sb.String())
 		}()
 
 		latest, err := cfg.Upgrade.FetchLatest()
