@@ -6,8 +6,8 @@ import (
 
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 )
 
 type UpgradeCache struct {
@@ -76,7 +76,7 @@ func (u *Upgrade) checkUpdate(current string) (*UpgradeCache, error) {
 		Interval: cache.Duration(duration),
 	}
 
-	latest, err := cfg.Latest()
+	latest, err := cfg.FetchLatest()
 	if err != nil {
 		return nil, err
 	}
