@@ -9,7 +9,7 @@ import (
 //go:embed scripts/omp.bash
 var bashInit string
 
-func (f Feature) Bash() Code {
+func (f Features) Bash() Code {
 	switch f {
 	case CursorPositioning:
 		return unixCursorPositioning
@@ -49,7 +49,7 @@ bleopt prompt_ps1_final='$(
         --shell-version="$BASH_VERSION" \
         --escape=false
 )'`
-	case PromptMark, PoshGit, Azure, LineError, Jobs, Tooltips:
+	case PromptMark, PoshGit, Azure, LineError, Jobs, Tooltips, Async:
 		fallthrough
 	default:
 		return ""
@@ -57,7 +57,7 @@ bleopt prompt_ps1_final='$(
 }
 
 func QuotePosixStr(str string) string {
-	if len(str) == 0 {
+	if str == "" {
 		return "''"
 	}
 
